package App::lasttouch ;  
our $VERSION = '0.041' ; 
our $DATE = '2023-03-25T23:50+09:00' ; 

=encoding utf8

=head1 NAME

App::lasttouch -- 指定ディレクトリのファイル全て(直下のみでない)に対して、最後に変更された順で網羅的に表示する。

=head1 SYNOPSIS

This module provides a Unix-like command `F<lasttouch>'.

=head1 DESCRIPTION


=head1 AUTHOR

下野寿之 Toshiyuki SHIMONO <bin4tsv@gmail.com> 

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2019-2023 Toshiyuki SHIMONO. All rights reserved.
This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

=cut

1 ;
